aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-dcerpc-ubikvote.c
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2007-09-07 22:11:01 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2007-09-07 22:11:01 +0000
commit78ce9fba16b8fed959287799d5b50a2798ff32a8 (patch)
treec5d273d55f1d31afb102830d6fc134e696761e90 /epan/dissectors/packet-dcerpc-ubikvote.c
parentfe0cc23d5af5884d2a88a08816f71d8ebb4034d9 (diff)
Change the long protocol name dissectors for various DFS protocols to
indicate that they're for DFS; update comments as well. Rename packet-dcerpc-afs4int.c to packet-dcerpc-fileexp.c, and change the short and filter names for the protocol, and the names for the filterable fields, to reflect the fact that it's for the File Exporter protocol in DFS. ("AFS 4" = DCE DFS.) git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@22827 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/dissectors/packet-dcerpc-ubikvote.c')
-rw-r--r--epan/dissectors/packet-dcerpc-ubikvote.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-dcerpc-ubikvote.c b/epan/dissectors/packet-dcerpc-ubikvote.c
index 2427201ca1..5edffce40e 100644
--- a/epan/dissectors/packet-dcerpc-ubikvote.c
+++ b/epan/dissectors/packet-dcerpc-ubikvote.c
@@ -1,6 +1,6 @@
/* packet-dcerpc-ubikvote.c
*
* Routines for dcerpc Ubik Voting routines.
* Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
* This information is based off the released idl files from opengroup.
* ftp://ftp.opengroup.org/pub/dce122/dce/src/file.tar.gz file/ncsubik/ubikvote_proc.idl
@@ -77,7 +77,7 @@ proto_register_ubikvote (void)
static gint *ett[] = {
&ett_ubikvote,
};
- proto_ubikvote = proto_register_protocol ("DCE/RPC FLDB UBIKVOTE", "UBIKVOTE", "ubikvote");
+ proto_ubikvote = proto_register_protocol ("DCE DFS FLDB UBIKVOTE", "UBIKVOTE", "ubikvote");
proto_register_field_array (proto_ubikvote, hf, array_length (hf));
proto_register_subtree_array (ett, array_length (ett));
}
@@ -1,6 +1,6 @@
/* packet-dcerpc-ubikvote.c
*
- * Routines for dcerpc Ubik Voting routines.
+ * Routines for DCE DFS Ubik Voting routines.
* Copyright 2002, Jaime Fournier <Jaime.Fournier@hush.com>
* This information is based off the released idl files from opengroup.